DoWhy documentation
===================

.. toctree::
    :maxdepth: 3
    :hidden:
    :glob:

    getting_started/index
    User Guide <user_guide/index>
    Examples <example_notebooks/nb_index>
    dowhy
    Contributing <contributing>
    code_repo

**Date**: |today| **Version**: |version|


**Related resources**:
`Source Repository <https://github.com/py-why/dowhy>`__ |
`Issues & Ideas <https://github.com/py-why/dowhy/issues>`__ |
`Join the Community (Discord) <https://discord.gg/cSBGb3vsZb>`__
`PyWhy Organization <https://www.pywhy.org>`__ |
`DoWhy on PyPI <https://pypi.org/project/dowhy>`__ |

Much like machine learning libraries have done for prediction, DoWhy is a Python library that aims to spark
causal thinking and analysis. DoWhy provides a wide variety of algorithms for effect estimation, causal
structure learning, diagnosis of causal structures, root cause analysis, interventions and counterfactuals.

.. grid:: 1 2 2 2
    :gutter: 4

    .. grid-item-card:: Getting started
        :shadow: md
        :link: getting_started/index
        :link-type: doc

        :octicon:`rocket;2em;sd-text-info`
        ^^^
        New to DoWhy? Our Getting started guide will get you up to speed in minutes. It'll help you install DoWhy and
        write your first lines of code. Once completed, you'll be ready to the run examples and follow along in the
        User Guide.

    .. grid-item-card:: User Guide
        :shadow: md
        :link: user_guide/intro
        :link-type: doc

        :octicon:`book;2em;sd-text-info`
        ^^^
        Complete newbie when it comes to causal inference and DoWhy? Then you probably want to read our
        comprehensive User Guide. It guides you through everything you need to know, including the concepts and
        science you need to know when trying to solve non-trivial problems.

    .. grid-item-card:: Examples
        :shadow: md
        :link: example_notebooks/nb_index
        :link-type: doc

        :octicon:`video;2em;sd-text-info`
        ^^^
        If you prefer to learn by example, we recommend to browse the examples. It covers a wide variety of problems
        that you can use to liken to your own problem.

    .. grid-item-card:: API Reference
        :shadow: md
        :link: dowhy
        :link-type: doc

        :octicon:`code;2em;sd-text-info`
        ^^^
        The API reference contains a detailed description of the functions, modules, and objects included in DoWhy.
        It assumes that you have an understanding of the key concepts.
